==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/geo28.h <==
/*!***************************************************************************

  module      : geo28.h

  -------------------------------------------------------------------------

  responsible : RaymondR

  special area: Profile Container Class
  description : This container class is used to handle the storage of
                profile data. 
                
                Profile data has arbitrary length, but can
                be identified by a userid/SERVERDB combination.
                Each profile consists of length + bytestream.

                The profile data is only accessable via this interface.
                This is acting not on a ASCII-file....

                SERVERDB is used to identify a container file on per
                database base.

  last changed: 1999-11-10  14:54
  see also    : http://pwww/Tools/Autorisierung-Ergebnis981013.html

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "geo200.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#define FIRST_TOKEN_EO28      0
#define LAST_TOKEN_EO28       ((tsp00_Uint4)-1)
#define NO_TOKEN_EO28         ((tsp00_Uint4)-2)

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/

/*
  Class: t_FileContainer
 */
class t_FileContainer;

/*!
  Class: teo28_ProfileContainer
 */
class teo28_ProfileContainer
{
public:
  /*!
    Function:     teo28_ProfileContainer
    description:  Constructor 

                  This allocates internal resources.
    arguments:    ServerDB   [in]    - SERVERDB name used to find container image
                  pEventList [inout] - The event list to be used,
                                     - if NULL throw EventList on error
    return value: none, but setting *pEventList on error.
   */
  teo28_ProfileContainer( tsp00_DbNamec const ServerDB,
                          teo200_EventList *  pEventList=NULL );

  /*!
    Function:     ~teo28_ProfileContainer
    description:  Destructor

                  This flushes the profiles cached and frees memory.
    arguments:    none
    return value: none
   */
  ~teo28_ProfileContainer();

  /*!
    Function:     eo28_DeleteProfileContainer
    description:  Delete profile container.

                  Removes the profile container with all its profiles.

    arguments:    pEventList   [inout] - The event list to be used,
                                         if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_DeleteProfileContainer( teo200_EventList *    pEventList = NULL );

  /*!
    Function:     eo28_GetOwnerName
    description:  Retrieve owner name of Profile Container
    
                  Uses Id of Profile Container creator to return Username of owner
                  
    arguments:    Username     [out]   - The returned owner name of the profile container
                  pEventList   [inout] - The event list to be used,
                                         if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_GetOwnerName( tsp00_UserNamec  &    Username,
                          teo200_EventList *    pEventList = NULL );

  /*!
    Function: eo28_SetProfile
    description: Set (Add or Update) a profile in ProfileContainer.

                 All given data is copied.

    arguments: UserName        [in]    - The Username to add
               Length          [in]    - The length of the profile data
               pProfile        [in]    - The pointer to the profile data
               pEventList      [inout] - The event list to be used,
                                         if NULL throw EventList on error
    return value: true if added
                  false else (setting *pEventList)
   */
  bool eo28_SetProfile( tsp00_UserNamec const UserName,
                        tsp00_Int4  const     Length,
                        void * const          pProfile,
                        teo200_EventList *    pEventList = NULL );

  /*!
    Function: eo28_DelProfile
    description: Delete a specific profile from ProfileContainer

    arguments: UserName     [in]    - The Username connected with profile
               pEventList   [inout] - The event list to be used,
                                      if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_DelProfile( tsp00_UserNamec const  UserName, 
                        teo200_EventList *     pEventList = NULL );
  /*!
    Function: eo28_GetProfile
    description: Get a specific profile from ProfileContainer

                 In case of error (returning false) check length 
                 to make sure not only the buffer size was insufficient.

    arguments: UserName     [in]    - The Username connected with profile
               Length       [inout] - On Input length of pBuffer given, on
                                      output always the length of the 
                                      profile_data.
               pProfile     [in]    - The pointer to the caller supplied buffer
                                      for profile data. If NULL caller is not
                                      interested in profile data.
               pEventList   [inout] - The event list to be used,
                                      if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_GetProfile( tsp00_UserNamec const  UserName, 
                        tsp00_Int4             &Length,
                        void * const           pProfile,
                        teo200_EventList *     pEventList = NULL );

  /*!
    Function: eo28_ScanProfiles
    description: Scan ProfileContainer and return next profile
    
                 Using a token, which must be set to FIRST_TOKEN_EO28
                 to get the first profile, all profiles are returned
                 in order they are found by repeated calls to this function.
                 In such case reuse token.

                 Any delete or insert operation ('eo28_DelProfile' or
                 'eo28_SetProfile') during repeated calls to 'eo28_ScanProfiles'
                 will reset the token to FIRST_TOKEN_EO28.

                 If the last profile was found, the token will be set to 
                 LAST_TOKEN_EO28.
                 
                 If no profile was found, the token will be set to 
                 NO_TOKEN_EO28.

                 To get only the username and profile length without the profile 
                 data, set pBuffer input parameter to NULL.

                 WARNING -- CHECKING THE RETURN CODE IS MANDATORY -- WARNING

                 In case of error (returning false) check length 
                 to make sure not only the buffer size was insufficient.
                 In such a case you can reuse token, but you will end up in
                 an endless loop if you do not check the return code...

    arguments: token        [inout] - Enumeration token, updated in case of
                                      success, otherwise untouched!
                                      Start with FIRST_TOKEN_EO28.
                                      LAST_TOKEN_EO28 signals that 
                                      the last profile was found.
               Length       [inout] - On Input length of pBuffer given, on
                                      output always the length of the 
                                      profile_data.
               pProfile     [in]    - The pointer to the caller supplied buffer
                                      for profile_data. If NULL caller is not
                                      interested in profile data.
               UserName     [out]   - The Username of the entry found
               pEventList   [out]   - The event list to be used,
                                      if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_ScanProfiles( tsp00_Uint4         &Token,
                          tsp00_Int4          &Length,
                          void * const        pProfile,
                          tsp00_UserNamec     &UserName,
                          teo200_EventList *  pEventList = NULL );

private:
  t_FileContainer    *m_pContainer;
  bool               m_Open;
};
/*!
  EndClass: teo28_ProfileContainer
 */

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/geo28.h <==
/*!***************************************************************************

  module      : geo28.h

  -------------------------------------------------------------------------

  responsible : RaymondR

  special area: Profile Container Class
  description : This container class is used to handle the storage of
                profile data. 
                
                Profile data has arbitrary length, but can
                be identified by a userid/SERVERDB combination.
                Each profile consists of length + bytestream.

                The profile data is only accessable via this interface.
                This is acting not on a ASCII-file....

                SERVERDB is used to identify a container file on per
                database base.

  last changed: 1999-11-10  14:54
  see also    : http://pwww/Tools/Autorisierung-Ergebnis981013.html

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "geo200.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#define FIRST_TOKEN_EO28      0
#define LAST_TOKEN_EO28       ((tsp00_Uint4)-1)
#define NO_TOKEN_EO28         ((tsp00_Uint4)-2)

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/

/*
  Class: t_FileContainer
 */
class t_FileContainer;

/*!
  Class: teo28_ProfileContainer
 */
class teo28_ProfileContainer
{
public:
  /*!
    Function:     teo28_ProfileContainer
    description:  Constructor 

                  This allocates internal resources.
    arguments:    ServerDB   [in]    - SERVERDB name used to find container image
                  ReadOnly   [in]    - Open profile container in read only mode.
                  pEventList [inout] - The event list to be used,
                                     - if NULL throw EventList on error
    return value: none, but setting *pEventList on error.
   */
  teo28_ProfileContainer( tsp00_DbNamec const ServerDB,
                          bool                ReadOnly,
                          teo200_EventList *  pEventList = NULL );

  teo28_ProfileContainer( tsp00_DbNamec const ServerDB,
                          teo200_EventList *  pEventList = NULL );

  /*!
    Function:     ~teo28_ProfileContainer
    description:  Destructor

                  This flushes the profiles cached and frees memory.
    arguments:    none
    return value: none
   */
  ~teo28_ProfileContainer();

  /*!
    Function:     eo28_DeleteProfileContainer
    description:  Delete profile container.

                  Removes the profile container with all its profiles.

    arguments:    pEventList   [inout] - The event list to be used,
                                         if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_DeleteProfileContainer( teo200_EventList *    pEventList = NULL );

  /*!
    Function:     eo28_CloseProfileContainer
    description:  Close profile container.

                  close the profile container 

    arguments:    pEventList   [inout] - The event list to be used,
                                         if NULL throw EventList on error
    return value: true if closed
                  false else (setting *pEventList)
   */
  bool eo28_CloseProfileContainer( teo200_EventList *    pEventList = NULL );

  /*!
    Function:     eo28_GetOwnerName
    description:  Retrieve owner name of Profile Container
    
                  Uses Id of Profile Container creator to return Username of owner
                  
    arguments:    Username     [out]   - The returned owner name of the profile container
                  pEventList   [inout] - The event list to be used,
                                         if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_GetOwnerName( tsp00_C18c  &         Username,
                          teo200_EventList *    pEventList = NULL );

  /*!
    Function: eo28_SetProfile
    description: Set (Add or Update) a profile in ProfileContainer.

                 All given data is copied.

    arguments: UserName        [in]    - The Username to add
               Length          [in]    - The length of the profile data
               pProfile        [in]    - The pointer to the profile data
               pEventList      [inout] - The event list to be used,
                                         if NULL throw EventList on error
    return value: true if added
                  false else (setting *pEventList)
   */
  bool eo28_SetProfile( tsp00_C18c const      UserName,
                        tsp00_Int4  const     Length,
                        void * const          pProfile,
                        teo200_EventList *    pEventList = NULL );

  /*!
    Function: eo28_DelProfile
    description: Delete a specific profile from ProfileContainer

    arguments: UserName     [in]    - The Username connected with profile
               pEventList   [inout] - The event list to be used,
                                      if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_DelProfile( tsp00_C18c const       UserName, 
                        teo200_EventList *     pEventList = NULL );
  /*!
    Function: eo28_GetProfile
    description: Get a specific profile from ProfileContainer

                 In case of error (returning false) check length 
                 to make sure not only the buffer size was insufficient.

    arguments: UserName     [in]    - The Username connected with profile
               Length       [inout] - On Input length of pBuffer given, on
                                      output always the length of the 
                                      profile_data.
               pProfile     [in]    - The pointer to the caller supplied buffer
                                      for profile data. If NULL caller is not
                                      interested in profile data.
               pEventList   [inout] - The event list to be used,
                                      if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_GetProfile( tsp00_C18c const       UserName, 
                        tsp00_Int4             &Length,
                        void * const           pProfile,
                        teo200_EventList *     pEventList = NULL );

  /*!
    Function: eo28_ScanProfiles
    description: Scan ProfileContainer and return next profile
    
                 Using a token, which must be set to FIRST_TOKEN_EO28
                 to get the first profile, all profiles are returned
                 in order they are found by repeated calls to this function.
                 In such case reuse token.

                 Any delete or insert operation ('eo28_DelProfile' or
                 'eo28_SetProfile') during repeated calls to 'eo28_ScanProfiles'
                 will reset the token to FIRST_TOKEN_EO28.

                 If the last profile was found, the token will be set to 
                 LAST_TOKEN_EO28.
                 
                 If no profile was found, the token will be set to 
                 NO_TOKEN_EO28.

                 To get only the username and profile length without the profile 
                 data, set pBuffer input parameter to NULL.

                 WARNING -- CHECKING THE RETURN CODE IS MANDATORY -- WARNING

                 In case of error (returning false) check length 
                 to make sure not only the buffer size was insufficient.
                 In such a case you can reuse token, but you will end up in
                 an endless loop if you do not check the return code...

    arguments: token        [inout] - Enumeration token, updated in case of
                                      success, otherwise untouched!
                                      Start with FIRST_TOKEN_EO28.
                                      LAST_TOKEN_EO28 signals that 
                                      the last profile was found.
               Length       [inout] - On Input length of pBuffer given, on
                                      output always the length of the 
                                      profile_data.
               pProfile     [in]    - The pointer to the caller supplied buffer
                                      for profile_data. If NULL caller is not
                                      interested in profile data.
               UserName     [out]   - The Username of the entry found
               pEventList   [out]   - The event list to be used,
                                      if NULL throw EventList on error
    return value: true if deleted or not existing
                  false else (setting *pEventList)
   */
  bool eo28_ScanProfiles( tsp00_Uint4         &Token,
                          tsp00_Int4          &Length,
                          void * const        pProfile,
                          tsp00_C18c          &UserName,
                          teo200_EventList *  pEventList = NULL );

private:
  t_FileContainer    *m_pContainer;
  bool               m_Open;
};
/*!
  EndClass: teo28_ProfileContainer
 */

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
